@@ -34,7 +34,6 @@ class AdbExt(object):
     def __dump_xml(self):
         # 使用 helper 获取 xml
         xml_str = self.run_helper_cmd('layout')
-        xml_str = None
 
         # 使用压缩模式
         if not xml_str:
@@ -82,7 +81,7 @@ class AdbExt(object):
         if len(out) > 50:
             out = base64.b64decode(out)
         else:  # helper 截图失败，使用 screencap 截图
-            logging.warning('minicap 截图失败')
+            logging.warning('helper 截图失败')
             arg = 'adb -s {} exec-out screencap -p'.format(self.util.sn)
             out = self.util.cmd(arg, encoding=None)  # 这里是 png bytes string
 
